@@ -1,8 +1,8 @@
 import tensorflow as tf
-import cv2
+# import cv2
 from PIL import Image
 import numpy as np
-from typing import Dict,List, Callable
+from typing import Dict,List, Callable,Tuple
 
 max_crop_width = 100
 max_crop_height = 100
@@ -28,10 +28,72 @@ class ImageDatasetUtil():
 
     def __init__(self):
         pass
+
     
+    def limit_label(dataset:tf.data.Dataset, lower:int , upper:int)->tf.data.Dataset:
+        """ 指定(を含む)範囲内のラベルのみに制限したデータセットを提供する。
+        Arguments:
+            dataset -- 分割するデータセット
+            min -- ラベルの下限（含む）
+            max -- ラベルの上限(含む)
+        """
+
+        return dataset.filter(lambda data: (data['label'] >= lower and data['label'] <= upper ))
+
 
     @classmethod
-    def devide_train_validation(cls, dataset:tf.data.Dataset, length:int, ratio:float)->((tf.data.Dataset,int),(tf.data.Dataset,int)):
+    def to_contrasvie_fit(cls, dataset:tf.data.Dataset, shuffle_size=0, batch_size=50)->tf.data.Dataset:
+        """画像分類用の定番処理を実施する
+        
+        Arguments:
+            dataset -- 分割するデータセット
+            classes -- 分類クラスの数(one-hot化する)
+            shuffle_size -- シャッフルするバッファーのサイズ
+            batch_size -- バッチサイズ
+        
+        Returns:
+            Dataset -- データセット(正規化された画像データ,one-hot化されたラベルを提供)
+        """
+
+        def map_contrastive(data):
+            image = tf.cast(data['image'],tf.float32)
+            image = image / 255.0
+            return (image,image)
+
+        dataset = dataset.map(map_contrastive)
+
+        if shuffle_size > 0:
+             dataset = dataset.shuffle(shuffle_size)
+
+        dataset = dataset.batch(batch_size).repeat()
+        return dataset
+
+
+
+    @classmethod
+    def to_classification_fit(cls,dataset:tf.data.Dataset, classes=10, shuffle_size=0, batch_size=50)->tf.data.Dataset:
+        """画像分類用の定番処理を実施する
+        
+        Arguments:
+            dataset -- 分割するデータセット
+            classes -- 分類クラスの数(one-hot化する)
+            shuffle_size -- シャッフルするバッファーのサイズ
+            batch_size -- バッチサイズ
+        
+        Returns:
+            Dataset -- データセット(正規化された画像データ,one-hot化されたラベルを提供)
+        """
+        dataset = dataset.map(cls.dataset_init_classification)
+        dataset = dataset.map(cls.dict_to_classification_tuple)
+
+        if shuffle_size > 0:
+            dataset = dataset.shuffle(shuffle_size)
+
+        dataset = dataset.batch(batch_size).repeat()
+        return dataset
+
+    @classmethod
+    def devide_train_validation(cls, dataset:tf.data.Dataset, length:int, ratio:float)->Tuple[Tuple[tf.data.Dataset,int],Tuple[tf.data.Dataset,int]]:
         """学習用と検証用のデータセットに分割する。
         
         Arguments:
@@ -51,11 +113,11 @@ class ImageDatasetUtil():
 
 
     @classmethod
-    def k_fold_cross_validation_dataset(cls, dataset:tf.data.Dataset, length:int, ratio:float)->((tf.data.Dataset,int),(tf.data.Dataset,int)):
+    def k_fold_cross_validation_dataset(cls, dataset:tf.data.Dataset, length:int, ratio:float)->Tuple[Tuple[tf.data.Dataset,int],Tuple[tf.data.Dataset,int]]:
         pass        
 
     @classmethod
-    def count_image_dataset(cls, dataset:tf.data.Dataset)->(int, Dict):
+    def count_image_dataset(cls, dataset:tf.data.Dataset)->Tuple[int, Dict]:
         """データセットのラベルごとの数を数える。
         
         Arguments:
@@ -94,7 +156,7 @@ class ImageDatasetUtil():
 
     @classmethod
     def image_reguralization(cls, offset:float=0.0):
-        """画像データを正則化するmap関数を作成する。
+        """画像データを正規化するmap関数を作成する。
         
         Keyword Arguments:
             offset {float} -- [description] (default: {0.0})
@@ -132,7 +194,7 @@ class ImageDatasetUtil():
         Returns:
             [type]: [description]
         """
-        def __dict_to_classification_tuple(data:Dict)->(tf.Tensor,tf.Tensor):
+        def __dict_to_classification_tuple(data:Dict):
             return (data["image"], data["label"])
         return __dict_to_classification_tuple
     
@@ -144,7 +206,7 @@ class ImageDatasetUtil():
         Returns:
             [type]: [description]
         """
-        def dict_to_ae_tuple(data:Dict)->(tf.Tensor,tf.Tensor):
+        def dict_to_ae_tuple(data:Dict)->Tuple[tf.Tensor,tf.Tensor]:
             return (data["image"], data["image"])
         return dict_to_ae_tuple
 
@@ -198,31 +260,31 @@ class ImageDatasetUtil():
 
 class ImageUtil():
 
-    @classmethod
-    def pil2cv(cls, image):
-        ''' PIL型 -> OpenCV型 '''
-        new_image = np.array(image, dtype=np.uint8)
-        if new_image.ndim == 2:  # モノクロ
-            pass
-        elif new_image.shape[2] == 3:  # カラー
-            new_image = cv2.cvtColor(new_image, cv2.COLOR_RGB2BGR)
-        elif new_image.shape[2] == 4:  # 透過
-            new_image = cv2.cvtColor(new_image, cv2.COLOR_RGBA2BGRA)
-        return new_image
+    # @classmethod
+    # def pil2cv(cls, image):
+    #     ''' PIL型 -> OpenCV型 '''
+    #     new_image = np.array(image, dtype=np.uint8)
+    #     if new_image.ndim == 2:  # モノクロ
+    #         pass
+    #     elif new_image.shape[2] == 3:  # カラー
+    #         new_image = cv2.cvtColor(new_image, cv2.COLOR_RGB2BGR)
+    #     elif new_image.shape[2] == 4:  # 透過
+    #         new_image = cv2.cvtColor(new_image, cv2.COLOR_RGBA2BGRA)
+    #     return new_image
 
 
-    @classmethod
-    def cv2pil(cls, image):
-        ''' OpenCV型 -> PIL型 '''
-        new_image = image.copy()
-        if new_image.ndim == 2:  # モノクロ
-            pass
-        elif new_image.shape[2] == 3:  # カラー
-            new_image = cv2.cvtColor(new_image, cv2.COLOR_BGR2RGB)
-        elif new_image.shape[2] == 4:  # 透過
-            new_image = cv2.cvtColor(new_image, cv2.COLOR_BGRA2RGBA)
-        new_image = Image.fromarray(new_image)
-        return new_image
+    # @classmethod
+    # def cv2pil(cls, image):
+    #     ''' OpenCV型 -> PIL型 '''
+    #     new_image = image.copy()
+    #     if new_image.ndim == 2:  # モノクロ
+    #         pass
+    #     elif new_image.shape[2] == 3:  # カラー
+    #         new_image = cv2.cvtColor(new_image, cv2.COLOR_BGR2RGB)
+    #     elif new_image.shape[2] == 4:  # 透過
+    #         new_image = cv2.cvtColor(new_image, cv2.COLOR_BGRA2RGBA)
+    #     new_image = Image.fromarray(new_image)
+    #     return new_image
 
 
     @classmethod
