@@ -1,6 +1,7 @@
 import tensorflow as tf
 
 from abc import ABC, abstractclassmethod, abstractmethod
+from typing import Tuple
 import tensorflow as tf
 
 
@@ -10,13 +11,13 @@ class AbstractClassificationModel(ABC):
         pass
 
     @abstractclassmethod
-    def get_base_model(cls,input:(int,int,int),include_top:bool,weights:str,**kwargs)->tf.keras.Model:
+    def get_base_model(cls,input:Tuple[int,int,int],include_top:bool,weights:str,**kwargs)->tf.keras.Model:
         raise NotImplementedError()
 
     @classmethod
-    def get_model(cls, input_shape:(int,int,int), include_top=False, weights=None, classes=1000, **kwargs)-> tf.keras.Model:
+    def get_model(cls, input_shape:Tuple[int,int,int], include_top=False, weights=None, classes=1000, **kwargs)-> tf.keras.Model:
         base = cls.get_base_model(input_shape,include_top, weights, **kwargs)
-        model = ClassificationModel.get_classify_model(base,classes)
+        model = ClassificationModelBuilder.build_classify_model(base,classes)
         return model
 
 class SimpleClassificationModel(AbstractClassificationModel):
@@ -24,7 +25,7 @@ class SimpleClassificationModel(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str,**kwargs) -> tf.keras.Model:
+    def get_base_model(cls,input_shape:Tuple[int,int,int],include_top:bool,weights:str,**kwargs) -> tf.keras.Model:
         inputs = tf.keras.Input(shape=input_shape,name='image')
         x = tf.keras.layers.Conv2D(filters=32,kernel_size=(3,3),padding="same")(inputs)
         x = tf.keras.layers.Activation('relu')(x)
@@ -49,7 +50,7 @@ class KerasResNet50(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
+    def get_base_model(cls,input_shape:Tuple[int,int,int],include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
         model = tf.keras.applications.ResNet50(include_top=False, weights=weights, input_shape=input_shape)
         return model
 
@@ -59,7 +60,7 @@ class KerasResNet50V2(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
+    def get_base_model(cls,input_shape:Tuple[int,int,int],include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
         model = tf.keras.applications.ResNet50V2(include_top=False, weights=weights, input_shape=input_shape)
         return model
 
@@ -69,7 +70,7 @@ class KerasMobileNetV2(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
+    def get_base_model(cls,input_shape:Tuple[int,int,int],include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
         model = tf.keras.applications.MobileNetV2(include_top=False, weights=weights, input_shape=input_shape)
         return model
 
@@ -79,7 +80,7 @@ class KerasInceptionResNetV2(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
+    def get_base_model(cls,input_shape:Tuple[int,int,int],include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
         model = tf.keras.applications.InceptionResNetV2(include_top=False, weights=weights, input_shape=input_shape)
         return model
 
@@ -90,12 +91,12 @@ class KerasInceptionV3(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
+    def get_base_model(cls,input_shape:Tuple[int,int,int],include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
         model = tf.keras.applications.InceptionV3(include_top=False, weights=weights, input_shape=input_shape)
         return model
 
 
-class ClassificationModel():
+class ClassificationModelBuilder():
     """単純なSoftmaxによる分類モデルクラス
 
     """
@@ -105,16 +106,16 @@ class ClassificationModel():
 
         """
         x = AveragePooling2D(pool_size=(8, 8))(x)
-x = Dropout(.4)(x)
-x = Flatten()(x)
-predictions = Dense(n_classes, init='glorot_uniform', W_regularizer=l2(.0005), activation='softmax')(x)
+        x = Dropout(.4)(x)
+        x = Flatten()(x)
+        predictions = Dense(n_classes, init='glorot_uniform', W_regularizer=l2(.0005), activation='softmax')(x)
 
         Returns:
             [type] -- [description]
         """
 
     @classmethod
-    def get_classify_model(cls, base_model:tf.keras.Model, classes:int)->tf.keras.Model:        
+    def build_classify_model(cls, base_model:tf.keras.Model, classes:int)->tf.keras.Model:        
         input = base_model.input
         last = base_model.output
         
@@ -129,4 +130,3 @@ predictions = Dense(n_classes, init='glorot_uniform', W_regularizer=l2(.0005), a
             x = tf.keras.layers.Dense(classes,dtype='float32',kernel_initializer='he_normal')(x)
             x = tf.keras.layers.Activation('sigmoid',dtype='float32')(x)
         return tf.keras.Model(input,x)
-
